# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImcRecalledMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ImcNoticeMessage_pb2 as ImcNoticeMessage__pb2
import Message_pb2 as Message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ImcRecalledMessage.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x16ImcNoticeMessage.proto\x1a\rMessage.proto\"\x89\x01\n\x12ImcRecalledMessage\x12\x31\n\toriginMsg\x18\x01 \x01(\x0b\x32\x1e.AcFunDanmu.Im.Message.Message\x12@\n\tnoticeMsg\x18\x02 \x01(\x0b\x32-.AcFunDanmu.Im.Cloud.Message.ImcNoticeMessageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ImcRecalledMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMCRECALLEDMESSAGE._serialized_start=97
  _IMCRECALLEDMESSAGE._serialized_end=234
# @@protoc_insertion_point(module_scope)
