# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SixinCustomPushType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19SixinCustomPushType.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update*@\n\x13SixinCustomPushType\x12\x15\n\x11INVALID_PUSH_TYPE\x10\x00\x12\x12\n\x0eRELATION_EVENT\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SixinCustomPushType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SIXINCUSTOMPUSHTYPE._serialized_start=62
  _SIXINCUSTOMPUSHTYPE._serialized_end=126
# @@protoc_insertion_point(module_scope)
