# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientStatisticalDataConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ClientStatisticalDataConfig.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Config\"g\n\x1b\x43lientStatisticalDataConfig\x12\x1f\n\x17\x63mdDataReportSampleRate\x18\x01 \x01(\x01\x12\'\n\x1fnetworkFlowCostReportSampleRate\x18\x02 \x01(\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ClientStatisticalDataConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLIENTSTATISTICALDATACONFIG._serialized_start=65
  _CLIENTSTATISTICALDATACONFIG._serialized_end=168
# @@protoc_insertion_point(module_scope)
