# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatTarget.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTargetType_pb2 as ChatTargetType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x43hatTarget.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x14\x43hatTargetType.proto\"Y\n\nChatTarget\x12\x10\n\x08targetId\x18\x01 \x01(\t\x12\x39\n\ntargetType\x18\x02 \x01(\x0e\x32%.AcFunDanmu.Im.Message.ChatTargetTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChatTarget_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHATTARGET._serialized_start=65
  _CHATTARGET._serialized_end=154
# @@protoc_insertion_point(module_scope)
