# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientConfigGetResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ClientConfig_pb2 as ClientConfig__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x43lientConfigGetResponse.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Config\x1a\x12\x43lientConfig.proto\"j\n\x17\x43lientConfigGetResponse\x12\x0f\n\x07version\x18\x01 \x01(\r\x12>\n\x0c\x63lientConfig\x18\x02 \x01(\x0b\x32(.AcFunDanmu.Im.Cloud.Config.ClientConfigb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ClientConfigGetResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLIENTCONFIGGETRESPONSE._serialized_start=81
  _CLIENTCONFIGGETRESPONSE._serialized_end=187
# @@protoc_insertion_point(module_scope)
