# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PublicGroupSearchResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import PublicGroupSearchInfo_pb2 as PublicGroupSearchInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fPublicGroupSearchResponse.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x1bPublicGroupSearchInfo.proto\"g\n\x19PublicGroupSearchResponse\x12J\n\x0fpublicGroupInfo\x18\x01 \x03(\x0b\x32\x31.AcFunDanmu.Im.Cloud.Search.PublicGroupSearchInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PublicGroupSearchResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLICGROUPSEARCHRESPONSE._serialized_start=92
  _PUBLICGROUPSEARCHRESPONSE._serialized_end=195
# @@protoc_insertion_point(module_scope)
