# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MultiMediaMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Media_pb2 as Media__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17MultiMediaMessage.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x0bMedia.proto\"c\n\x11MultiMediaMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x31\n\x05media\x18\x02 \x03(\x0b\x32\".AcFunDanmu.Im.Cloud.Message.Media\x12\r\n\x05\x65xtra\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MultiMediaMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MULTIMEDIAMESSAGE._serialized_start=69
  _MULTIMEDIAMESSAGE._serialized_end=168
# @@protoc_insertion_point(module_scope)
