# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UpdateVoiceCallExtraRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallParam_pb2 as CallParam__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!UpdateVoiceCallExtraRequest.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x0f\x43\x61llParam.proto\"k\n\x1bUpdateVoiceCallExtraRequest\x12\x0e\n\x06roomId\x18\x01 \x01(\t\x12<\n\tcallParam\x18\x02 \x01(\x0b\x32).AcFunDanmu.Im.Cloud.Voice.Call.CallParamb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UpdateVoiceCallExtraRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UPDATEVOICECALLEXTRAREQUEST._serialized_start=86
  _UPDATEVOICECALLEXTRAREQUEST._serialized_end=193
# @@protoc_insertion_point(module_scope)
